## 0.2.4 (2024-09-01)

### Fix

- **typing**: allow to pass Path objects

## 0.2.3 (2023-12-15)

### Fix

- **typing**: allow dict for the get method

## 0.2.2 (2023-12-14)

### Fix

- **compat**: make compatible down to python 3.8

## 0.2.1 (2023-12-13)

### Fix

- vary return type based on passed arg

## 0.2.0 (2023-11-30)

### Feat

- add shortcut function `get`

## 0.1.3 (2023-11-23)

### Fix

- add context for SopsyUnparsableOutpoutTypeError

## 0.1.2 (2023-11-22)

### Fix

- add license

## 0.1.1 (2023-11-22)

### Refactor

- make pyyaml optional

## 0.1.0 (2023-11-22)

### Feat

- release sopsy
